@@ -12,21 +12,24 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import datetime
 import uuid
 
 import mock
-from oslo_config import cfg
 from six.moves import range
 from testtools import matchers
 
 from keystone.common import driver_hints
+from keystone.common import sql
+import keystone.conf
 from keystone import exception
+from keystone.identity.backends import sql_model as model
 from keystone.tests import unit
 from keystone.tests.unit import default_fixtures
 from keystone.tests.unit import filtering
 
 
-CONF = cfg.CONF
+CONF = keystone.conf.CONF
 
 
 class IdentityTests(object):
@@ -44,20 +47,20 @@ class IdentityTests(object):
     def test_authenticate_bad_user(self):
         self.assertRaises(AssertionError,
                           self.identity_api.authenticate,
-                          context={},
+                          self.make_request(),
                           user_id=uuid.uuid4().hex,
                           password=self.user_foo['password'])
 
     def test_authenticate_bad_password(self):
         self.assertRaises(AssertionError,
                           self.identity_api.authenticate,
-                          context={},
+                          self.make_request(),
                           user_id=self.user_foo['id'],
                           password=uuid.uuid4().hex)
 
     def test_authenticate(self):
         user_ref = self.identity_api.authenticate(
-            context={},
+            self.make_request(),
             user_id=self.user_sna['id'],
             password=self.user_sna['password'])
         # NOTE(termie): the password field is left in user_sna to make
@@ -78,7 +81,7 @@ class IdentityTests(object):
         self.assignment_api.add_user_to_project(self.tenant_baz['id'],
                                                 new_user['id'])
         user_ref = self.identity_api.authenticate(
-            context={},
+            self.make_request(),
             user_id=new_user['id'],
             password=user['password'])
         self.assertNotIn('password', user_ref)
@@ -99,7 +102,7 @@ class IdentityTests(object):
 
         self.assertRaises(AssertionError,
                           self.identity_api.authenticate,
-                          context={},
+                          self.make_request(),
                           user_id=id_,
                           password='password')
 
@@ -118,6 +121,13 @@ class IdentityTests(object):
         self.user_foo.pop('password')
         self.assertDictEqual(self.user_foo, user_ref)
 
+    def test_get_user_returns_required_attributes(self):
+        user_ref = self.identity_api.get_user(self.user_foo['id'])
+        self.assertIn('id', user_ref)
+        self.assertIn('name', user_ref)
+        self.assertIn('enabled', user_ref)
+        self.assertIn('password_expires_at', user_ref)
+
     @unit.skip_if_cache_disabled('identity')
     def test_cache_layer_get_user(self):
         user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
@@ -387,12 +397,12 @@ class IdentityTests(object):
         # with a password that  is empty string or None
         self.assertRaises(AssertionError,
                           self.identity_api.authenticate,
-                          context={},
+                          self.make_request(),
                           user_id=user['id'],
                           password='')
         self.assertRaises(AssertionError,
                           self.identity_api.authenticate,
-                          context={},
+                          self.make_request(),
                           user_id=user['id'],
                           password=None)
 
@@ -405,12 +415,12 @@ class IdentityTests(object):
         # with a password that  is empty string or None
         self.assertRaises(AssertionError,
                           self.identity_api.authenticate,
-                          context={},
+                          self.make_request(),
                           user_id=user['id'],
                           password='')
         self.assertRaises(AssertionError,
                           self.identity_api.authenticate,
-                          context={},
+                          self.make_request(),
                           user_id=user['id'],
                           password=None)
 
@@ -444,31 +454,6 @@ class IdentityTests(object):
                           user['id'],
                           user)
 
-    def test_update_user_blank_name_fails(self):
-        user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
-        user = self.identity_api.create_user(user)
-        user['name'] = ''
-        self.assertRaises(exception.ValidationError,
-                          self.identity_api.update_user,
-                          user['id'],
-                          user)
-
-    def test_update_user_invalid_name_fails(self):
-        user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
-        user = self.identity_api.create_user(user)
-
-        user['name'] = None
-        self.assertRaises(exception.ValidationError,
-                          self.identity_api.update_user,
-                          user['id'],
-                          user)
-
-        user['name'] = 123
-        self.assertRaises(exception.ValidationError,
-                          self.identity_api.update_user,
-                          user['id'],
-                          user)
-
     def test_list_users(self):
         users = self.identity_api.list_users(
             domain_scope=self._set_domain_scope(
@@ -542,7 +527,7 @@ class IdentityTests(object):
         # NOTE(breton): below, attribute `enabled` is explicitly tested to be
         # equal True. assertTrue should not be used, because it converts
         # the passed value to bool().
-        self.assertIs(user_ref['enabled'], True)
+        self.assertIs(True, user_ref['enabled'])
 
     def test_update_user_name(self):
         user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
@@ -565,19 +550,6 @@ class IdentityTests(object):
         user_ref = self.identity_api.get_user(user_ref['id'])
         self.assertEqual(changed_name, user_ref['name'])
 
-    def test_update_user_enable_fails(self):
-        user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
-        user = self.identity_api.create_user(user)
-        user_ref = self.identity_api.get_user(user['id'])
-        self.assertTrue(user_ref['enabled'])
-
-        # Strings are not valid boolean values
-        user['enabled'] = 'false'
-        self.assertRaises(exception.ValidationError,
-                          self.identity_api.update_user,
-                          user['id'],
-                          user)
-
     def test_add_user_to_group(self):
         domain = self._get_domain_fixture()
         new_group = unit.new_group_ref(domain_id=domain['id'])
@@ -804,6 +776,21 @@ class IdentityTests(object):
                           self.identity_api.get_group,
                           group['id'])
 
+    def test_create_group_name_with_trailing_whitespace(self):
+        group = unit.new_group_ref(domain_id=CONF.identity.default_domain_id)
+        group_name = group['name'] = (group['name'] + '    ')
+        group_returned = self.identity_api.create_group(group)
+        self.assertEqual(group_returned['name'], group_name.strip())
+
+    def test_update_group_name_with_trailing_whitespace(self):
+        group = unit.new_group_ref(domain_id=CONF.identity.default_domain_id)
+        group_create = self.identity_api.create_group(group)
+        group_name = group['name'] = (group['name'] + '    ')
+        group_update = self.identity_api.update_group(group_create['id'],
+                                                      group)
+        self.assertEqual(group_update['id'], group_create['id'])
+        self.assertEqual(group_update['name'], group_name.strip())
+
     def test_get_group_by_name(self):
         group = unit.new_group_ref(domain_id=CONF.identity.default_domain_id)
         group_name = group['name']
@@ -987,6 +974,53 @@ class IdentityTests(object):
         user_ref = self.identity_api.get_user(user['id'])
         self.assertDictEqual(updated_user_ref, user_ref)
 
+    @unit.skip_if_no_multiple_domains_support
+    def test_list_domains_filtered_and_limited(self):
+        # The test is designed for multiple domains only
+        def create_domains(domain_count, domain_name_prefix):
+            for _ in range(domain_count):
+                domain_name = '%s-%s' % (domain_name_prefix, uuid.uuid4().hex)
+                domain = unit.new_domain_ref(name=domain_name)
+                self.domain_list[domain_name] = \
+                    self.resource_api.create_domain(domain['id'], domain)
+
+        def clean_up_domains():
+            for _, domain in self.domain_list.items():
+                domain['enabled'] = False
+                self.resource_api.update_domain(domain['id'], domain)
+                self.resource_api.delete_domain(domain['id'])
+
+        self.domain_list = {}
+        create_domains(2, 'domaingroup1')
+        create_domains(3, 'domaingroup2')
+
+        self.addCleanup(clean_up_domains)
+        unfiltered_domains = self.resource_api.list_domains()
+
+        # Should get back just 4 entities
+        self.config_fixture.config(list_limit=4)
+        hints = driver_hints.Hints()
+        entities = self.resource_api.list_domains(hints=hints)
+        self.assertThat(entities, matchers.HasLength(hints.limit['limit']))
+        self.assertTrue(hints.limit['truncated'])
+
+        # Get one exact item from the list
+        hints = driver_hints.Hints()
+        hints.add_filter('name', unfiltered_domains[3]['name'])
+        entities = self.resource_api.list_domains(hints=hints)
+        self.assertThat(entities, matchers.HasLength(1))
+        self.assertEqual(entities[0], unfiltered_domains[3])
+
+        # Get 2 entries
+        hints = driver_hints.Hints()
+        hints.add_filter('name', 'domaingroup1', comparator='startswith')
+        entities = self.resource_api.list_domains(hints=hints)
+        self.assertThat(entities, matchers.HasLength(2))
+        self.assertThat(entities[0]['name'],
+                        matchers.StartsWith('domaingroup1'))
+        self.assertThat(entities[1]['name'],
+                        matchers.StartsWith('domaingroup1'))
+
 
 class FilterTests(filtering.FilterTests):
     def test_list_entities_filtered(self):
@@ -1284,7 +1318,7 @@ class LimitTests(filtering.FilterTests):
         # return at least the 20 entries we created (there may be other
         # entities lying around created by other tests/setup).
         entities = self._list_entities(entity)()
-        self.assertTrue(len(entities) >= 20)
+        self.assertGreaterEqual(len(entities), 20)
         self._match_with_list(self.entity_lists[entity], entities)
 
     def test_list_users_filtered_and_limited(self):
@@ -1295,3 +1329,96 @@ class LimitTests(filtering.FilterTests):
 
     def test_list_projects_filtered_and_limited(self):
         self._test_list_entity_filtered_and_limited('project')
+
+
+class ShadowUsersTests(object):
+    def test_create_nonlocal_user_unique_constraint(self):
+        user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
+        user_created = self.shadow_users_api.create_nonlocal_user(user)
+        self.assertNotIn('password', user_created)
+        self.assertEqual(user_created['id'], user['id'])
+        self.assertEqual(user_created['domain_id'], user['domain_id'])
+        self.assertEqual(user_created['name'], user['name'])
+        new_user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
+        new_user['name'] = user['name']
+        self.assertRaises(exception.Conflict,
+                          self.shadow_users_api.create_nonlocal_user,
+                          new_user)
+
+    def test_create_nonlocal_user_does_not_create_local_user(self):
+        user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
+        new_nonlocal_user = self.shadow_users_api.create_nonlocal_user(user)
+        user_ref = self._get_user_ref(new_nonlocal_user['id'])
+        self.assertIsNone(user_ref.local_user)
+
+    def test_get_user(self):
+        user = unit.new_user_ref(domain_id=CONF.identity.default_domain_id)
+        user.pop('email')
+        user.pop('password')
+        user_created = self.shadow_users_api.create_nonlocal_user(user)
+        self.assertEqual(user_created['id'], user['id'])
+        user_found = self.shadow_users_api.get_user(user_created['id'])
+        self.assertItemsEqual(user_created, user_found)
+
+    def test_create_federated_user_unique_constraint(self):
+        federated_dict = unit.new_federated_user_ref()
+        user_dict = self.shadow_users_api.create_federated_user(federated_dict)
+        user_dict = self.shadow_users_api.get_user(user_dict["id"])
+        self.assertIsNotNone(user_dict["id"])
+        self.assertRaises(exception.Conflict,
+                          self.shadow_users_api.create_federated_user,
+                          federated_dict)
+
+    def test_get_federated_user(self):
+        federated_dict = unit.new_federated_user_ref()
+        user_dict_create = self.shadow_users_api.create_federated_user(
+            federated_dict)
+        user_dict_get = self.shadow_users_api.get_federated_user(
+            federated_dict["idp_id"],
+            federated_dict["protocol_id"],
+            federated_dict["unique_id"])
+        self.assertItemsEqual(user_dict_create, user_dict_get)
+        self.assertEqual(user_dict_create["id"], user_dict_get["id"])
+
+    def test_update_federated_user_display_name(self):
+        federated_dict = unit.new_federated_user_ref()
+        user_dict_create = self.shadow_users_api.create_federated_user(
+            federated_dict)
+        new_display_name = uuid.uuid4().hex
+        self.shadow_users_api.update_federated_user_display_name(
+            federated_dict["idp_id"],
+            federated_dict["protocol_id"],
+            federated_dict["unique_id"],
+            new_display_name)
+        user_ref = self.shadow_users_api._get_federated_user(
+            federated_dict["idp_id"],
+            federated_dict["protocol_id"],
+            federated_dict["unique_id"])
+        self.assertEqual(user_ref.federated_users[0].display_name,
+                         new_display_name)
+        self.assertEqual(user_dict_create["id"], user_ref.id)
+
+    def test_set_last_active_at(self):
+        self.config_fixture.config(group='security_compliance',
+                                   disable_user_account_days_inactive=90)
+        now = datetime.datetime.utcnow().date()
+        user_ref = self.identity_api.authenticate(
+            self.make_request(),
+            user_id=self.user_sna['id'],
+            password=self.user_sna['password'])
+        user_ref = self._get_user_ref(user_ref['id'])
+        self.assertGreaterEqual(now, user_ref.last_active_at)
+
+    def test_set_last_active_at_when_config_setting_is_none(self):
+        self.config_fixture.config(group='security_compliance',
+                                   disable_user_account_days_inactive=None)
+        user_ref = self.identity_api.authenticate(
+            self.make_request(),
+            user_id=self.user_sna['id'],
+            password=self.user_sna['password'])
+        user_ref = self._get_user_ref(user_ref['id'])
+        self.assertIsNone(user_ref.last_active_at)
+
+    def _get_user_ref(self, user_id):
+        with sql.session_for_read() as session:
+            return session.query(model.User).get(user_id)
