@@ -17,22 +17,35 @@ import json
 import uuid
 
 from keystoneclient.contrib.ec2 import utils as ec2_utils
-from oslo_config import cfg
 from six.moves import http_client
 from testtools import matchers
 
 from keystone.common import utils
+import keystone.conf
 from keystone.contrib.ec2 import controllers
+from keystone.credential.providers import fernet as credential_fernet
 from keystone import exception
 from keystone.tests import unit
+from keystone.tests.unit import ksfixtures
 from keystone.tests.unit import test_v3
 
 
-CONF = cfg.CONF
+CONF = keystone.conf.CONF
 CRED_TYPE_EC2 = controllers.CRED_TYPE_EC2
 
 
 class CredentialBaseTestCase(test_v3.RestfulTestCase):
+
+    def setUp(self):
+        super(CredentialBaseTestCase, self).setUp()
+        self.useFixture(
+            ksfixtures.KeyRepository(
+                self.config_fixture,
+                'credential',
+                credential_fernet.MAX_ACTIVE_KEYS
+            )
+        )
+
     def _create_dict_blob_credential(self):
         blob, credential = unit.new_ec2_credential(user_id=self.user['id'],
                                                    project_id=self.project_id)
@@ -172,6 +185,61 @@ class CredentialTestCase(CredentialBaseTestCase):
             body={'credential': ref})
         self.assertValidCredentialResponse(r, ref)
 
+    def test_update_credential_to_ec2_type(self):
+        """Call ``PATCH /credentials/{credential_id}``."""
+        # Create a credential without providing a project_id
+        ref = unit.new_credential_ref(user_id=self.user['id'])
+        r = self.post(
+            '/credentials',
+            body={'credential': ref})
+        self.assertValidCredentialResponse(r, ref)
+        credential_id = r.result.get('credential')['id']
+
+        # Updating the credential to ec2 requires a project_id
+        update_ref = {'type': 'ec2', 'project_id': self.project_id}
+        self.patch(
+            '/credentials/%(credential_id)s' % {
+                'credential_id': credential_id},
+            body={'credential': update_ref})
+
+    def test_update_credential_to_ec2_missing_project_id(self):
+        """Call ``PATCH /credentials/{credential_id}``."""
+        # Create a credential without providing a project_id
+        ref = unit.new_credential_ref(user_id=self.user['id'])
+        r = self.post(
+            '/credentials',
+            body={'credential': ref})
+        self.assertValidCredentialResponse(r, ref)
+        credential_id = r.result.get('credential')['id']
+
+        # Updating such credential to ec2 type without providing a project_id
+        # will fail
+        update_ref = {'type': 'ec2'}
+        self.patch(
+            '/credentials/%(credential_id)s' % {
+                'credential_id': credential_id},
+            body={'credential': update_ref},
+            expected_status=http_client.BAD_REQUEST)
+
+    def test_update_credential_to_ec2_with_previously_set_project_id(self):
+        """Call ``PATCH /credentials/{credential_id}``."""
+        # Create a credential providing a project_id
+        ref = unit.new_credential_ref(user_id=self.user['id'],
+                                      project_id=self.project_id)
+        r = self.post(
+            '/credentials',
+            body={'credential': ref})
+        self.assertValidCredentialResponse(r, ref)
+        credential_id = r.result.get('credential')['id']
+
+        # Since the created credential above already has a project_id, the
+        # update request will not fail
+        update_ref = {'type': 'ec2'}
+        self.patch(
+            '/credentials/%(credential_id)s' % {
+                'credential_id': credential_id},
+            body={'credential': update_ref})
+
     def test_delete_credential(self):
         """Call ``DELETE /credentials/{credential_id}``."""
         self.delete(
@@ -286,6 +354,13 @@ class TestCredentialTrustScoped(test_v3.RestfulTestCase):
         self.trustee_user = self.identity_api.create_user(self.trustee_user)
         self.trustee_user['password'] = password
         self.trustee_user_id = self.trustee_user['id']
+        self.useFixture(
+            ksfixtures.KeyRepository(
+                self.config_fixture,
+                'credential',
+                credential_fernet.MAX_ACTIVE_KEYS
+            )
+        )
 
     def config_overrides(self):
         super(TestCredentialTrustScoped, self).config_overrides()
