@@ -12,25 +12,37 @@
 
 import uuid
 
-from oslo_config import cfg
 from six.moves import http_client
 from six.moves import range
 from testtools import matchers
 
 from keystone.common import controller
+import keystone.conf
+from keystone.credential.providers import fernet as credential_fernet
 from keystone import exception
 from keystone.tests import unit
+from keystone.tests.unit import ksfixtures
 from keystone.tests.unit import test_v3
 from keystone.tests.unit import utils as test_utils
 
 
-CONF = cfg.CONF
+CONF = keystone.conf.CONF
 
 
 class ResourceTestCase(test_v3.RestfulTestCase,
                        test_v3.AssignmentTestMixin):
     """Test domains and projects."""
 
+    def setUp(self):
+        super(ResourceTestCase, self).setUp()
+        self.useFixture(
+            ksfixtures.KeyRepository(
+                self.config_fixture,
+                'credential',
+                credential_fernet.MAX_ACTIVE_KEYS
+            )
+        )
+
     # Domain CRUD tests
 
     def test_create_domain(self):
@@ -129,18 +141,21 @@ class ResourceTestCase(test_v3.RestfulTestCase,
         self.assertValidDomainResponse(r)
         self.assertIsNotNone(r.result['domain'])
 
-    def test_list_domains(self):
-        """Call ``GET /domains``."""
+    def test_list_head_domains(self):
+        """Call ``GET & HEAD /domains``."""
         resource_url = '/domains'
         r = self.get(resource_url)
         self.assertValidDomainListResponse(r, ref=self.domain,
                                            resource_url=resource_url)
+        self.head(resource_url, expected_status=http_client.OK)
 
-    def test_get_domain(self):
+    def test_get_head_domain(self):
         """Call ``GET /domains/{domain_id}``."""
-        r = self.get('/domains/%(domain_id)s' % {
-            'domain_id': self.domain_id})
+        resource_url = '/domains/%(domain_id)s' % {
+            'domain_id': self.domain_id}
+        r = self.get(resource_url)
         self.assertValidDomainResponse(r, self.domain)
+        self.head(resource_url, expected_status=http_client.OK)
 
     def test_update_domain(self):
         """Call ``PATCH /domains/{domain_id}``."""
@@ -541,12 +556,13 @@ class ResourceTestCase(test_v3.RestfulTestCase,
 
     # Project CRUD tests
 
-    def test_list_projects(self):
-        """Call ``GET /projects``."""
+    def test_list_head_projects(self):
+        """Call ``GET & HEAD /projects``."""
         resource_url = '/projects'
         r = self.get(resource_url)
         self.assertValidProjectListResponse(r, ref=self.project,
                                             resource_url=resource_url)
+        self.head(resource_url, expected_status=http_client.OK)
 
     def test_create_project(self):
         """Call ``POST /projects``."""
@@ -665,13 +681,13 @@ class ResourceTestCase(test_v3.RestfulTestCase,
         r = self.post(
             '/projects',
             body={'project': ref_child})
-        self.assertEqual(r.result['project']['domain_id'],
-                         self.project['domain_id'])
+        self.assertEqual(self.project['domain_id'],
+                         r.result['project']['domain_id'])
         ref_child['domain_id'] = self.domain['id']
         self.assertValidProjectResponse(r, ref_child)
 
     def _create_projects_hierarchy(self, hierarchy_size=1):
-        """Creates a single-branched project hierarchy with the specified size.
+        """Create a single-branched project hierarchy with the specified size.
 
         :param hierarchy_size: the desired hierarchy size, default is 1 -
                                a project with one child.
@@ -752,12 +768,13 @@ class ResourceTestCase(test_v3.RestfulTestCase,
         """Call ``POST /projects``."""
         self._create_projects_hierarchy()
 
-    def test_get_project(self):
-        """Call ``GET /projects/{project_id}``."""
-        r = self.get(
-            '/projects/%(project_id)s' % {
-                'project_id': self.project_id})
+    def test_get_head_project(self):
+        """Call ``GET & HEAD /projects/{project_id}``."""
+        resource_url = '/projects/%(project_id)s' % {
+            'project_id': self.project_id}
+        r = self.get(resource_url)
         self.assertValidProjectResponse(r, self.project)
+        self.head(resource_url, expected_status=http_client.OK)
 
     def test_get_project_with_parents_as_list_with_invalid_id(self):
         """Call ``GET /projects/{project_id}?parents_as_list``."""
@@ -953,7 +970,7 @@ class ResourceTestCase(test_v3.RestfulTestCase,
                       [p['id'] for p in r.result['projects']])
 
     def test_list_project_is_domain_filter_default(self):
-        """Default project list should not see projects acting as domains"""
+        """Default project list should not see projects acting as domains."""
         # Get the initial count of regular projects
         r = self.get('/projects?is_domain=False', expected_status=200)
         number_is_domain_false = len(r.result['projects'])
@@ -1254,7 +1271,7 @@ class ResourceTestCase(test_v3.RestfulTestCase,
             expected_status=http_client.FORBIDDEN)
 
     def test_delete_project(self):
-        """Call ``DELETE /projects/{project_id}``
+        """Call ``DELETE /projects/{project_id}``.
 
         As well as making sure the delete succeeds, we ensure
         that any credentials that reference this projects are
